@@ -23,6 +23,12 @@
 
 GetProteinFunction <- function(ProteinAccList , directorypath = NULL)
 {
+  
+  if(!has_internet())
+  {
+    message("Please connect to the internet as the package requires internect connection.")
+    return()
+  }
   ProteinInfoParsed_total = data.frame()
   baseUrl <- "http://www.uniprot.org/uniprot/"
   Colnames = "ec,comment(ABSORPTION),comment(CATALYTIC ACTIVITY),chebi,chebi(Catalytic activity),chebi(Cofactor),chebi-id,comment(COFACTOR),comment(ENZYME REGULATION),comment(FUNCTION),comment(KINETICS),comment(PATHWAY),comment(REDOX POTENTIAL),comment(TEMPERATURE DEPENDENCE),comment(PH DEPENDENCE),feature(ACTIVE SITE),feature(BINDING SITE),feature(DNA BINDING),feature(METAL BINDING),feature(NP BIND),feature(SITE)"
@@ -30,8 +36,15 @@ GetProteinFunction <- function(ProteinAccList , directorypath = NULL)
   for (ProteinAcc in ProteinAccList)
   {
     #to see if Request == 200 or not
-    Request <- GET(paste0(baseUrl , ProteinAcc,".xml"))
-
+    Request <- tryCatch(
+      {
+        GET(paste0(baseUrl , ProteinAcc,".xml") , timeout(10))
+      },error = function(cond)
+      {
+        message("Internet connection problem occurs and the function will return the original error")
+        message(cond)
+      }
+    ) 
     #this link return information in tab formate (format = tab)
     ProteinName_url <- paste0("?query=accession:",ProteinAcc,"&format=tab&columns=",Colnames)
     RequestUrl <- paste0(baseUrl , ProteinName_url)
@@ -41,6 +54,7 @@ GetProteinFunction <- function(ProteinAccList , directorypath = NULL)
       ProteinDataTable <- tryCatch(read.csv(RequestUrl, header = TRUE, sep = '\t'), error=function(e) NULL)
       if (!is.null(ProteinDataTable))
       {
+        ProteinDataTable <- ProteinDataTable[1,]
         ProteinInfoParsed <- as.data.frame(ProteinDataTable,row.names = ProteinAcc)
         # add Dataframes together if more than one accession
         ProteinInfoParsed_total <- rbind(ProteinInfoParsed_total, ProteinInfoParsed)
