@@ -23,6 +23,11 @@
 
 GetProteinGOInfo <- function(ProteinAccList , directorypath = NULL)
 {
+  if(!has_internet())
+  {
+    message("Please connect to the internet as the package requires internect connection.")
+    return()
+  }
   ProteinInfoParsed_total = data.frame()
 
   baseUrl <- "http://www.uniprot.org/uniprot/"
@@ -31,8 +36,15 @@ GetProteinGOInfo <- function(ProteinAccList , directorypath = NULL)
   for (ProteinAcc in ProteinAccList)
   {
     #to see if Request == 200 or not
-    Request <- GET(paste0(baseUrl , ProteinAcc,".xml"))
-
+    Request <- tryCatch(
+      {
+        GET(paste0(baseUrl , ProteinAcc,".xml") , timeout(10))
+      },error = function(cond)
+      {
+        message("Internet connection problem occurs and the function will return the original error")
+        message(cond)
+      }
+    )
     #this link return information in tab formate (format = tab)
     #columns = what to return from all of the information (see: https://www.uniprot.org/help/uniprotkb_column_names)
     ProteinName_url <- paste0("?query=accession:",ProteinAcc,"&format=tab&columns=",Colnames)
@@ -43,6 +55,7 @@ GetProteinGOInfo <- function(ProteinAccList , directorypath = NULL)
       ProteinDataTable <- tryCatch(read.csv(RequestUrl, header = TRUE, sep = '\t'), error=function(e) NULL)
       if (!is.null(ProteinDataTable))
       {
+        ProteinDataTable <- ProteinDataTable[1,]
         ProteinInfoParsed <- as.data.frame(ProteinDataTable,row.names = ProteinAcc)
         # add Dataframes together if more than one accession
         ProteinInfoParsed_total <- rbind(ProteinInfoParsed_total, ProteinInfoParsed)
