@@ -23,14 +23,26 @@
 
 GetTaxaidentifier <- function(ProteinAccList, directorypath = NULL)
 {
+  if(!has_internet())
+  {
+    message("Please connect to the internet as the package requires internect connection.")
+    return()
+  }
   ProteinInfoParsed_total = data.frame()
   baseUrl <- "http://www.uniprot.org/uniprot/"
   Colnames = "lineage-id(all),lineage-id(SUPERKINGDOM),lineage-id(KINGDOM),lineage-id(SUBKINGDOM),lineage-id(SUPERPHYLUM),lineage-id(PHYLUM),lineage-id(SUBPHYLUM),lineage-id(SUPERCLASS),lineage-id(CLASS),lineage-id(SUBCLASS),lineage-id(INFRACLASS),lineage-id(SUPERORDER),lineage-id(ORDER),lineage-id(SUBORDER),lineage-id(INFRAORDER),lineage-id(PARVORDER),lineage-id(SUPERFAMILY),lineage-id(FAMILY),lineage-id(SUBFAMILY),lineage-id(TRIBE),lineage-id(SUBTRIBE),lineage-id(GENUS),lineage-id(SUBGENUS),lineage-id(SPECIES GROUP),lineage-id(SPECIES SUBGROUP),lineage-id(SPECIES),lineage-id(SUBSPECIES),lineage-id(VARIETAS),lineage-id(FORMA)"
   for (ProteinAcc in ProteinAccList)
   {
     #to see if Request == 200 or not
-    Request <- GET(paste0(baseUrl , ProteinAcc,".xml"))
-
+    Request <- tryCatch(
+      {
+        GET(paste0(baseUrl , ProteinAcc,".xml") , timeout(60))
+      },error = function(cond)
+      {
+        message("Internet connection problem occurs and the function will return the original error")
+        message(cond)
+      }
+    )
     #this link return information in tab formate (format = tab)
     #columns = what to return from all of the information (see: https://www.uniprot.org/help/uniprotkb_column_names)
     ProteinName_url <- paste0("?query=accession:",ProteinAcc,"&format=tab&columns=", Colnames)
@@ -41,6 +53,7 @@ GetTaxaidentifier <- function(ProteinAccList, directorypath = NULL)
       ProteinDataTable <- tryCatch(read.csv(RequestUrl, header = TRUE, sep = '\t'), error=function(e) NULL)
       if (!is.null(ProteinDataTable))
       {
+        ProteinDataTable <- ProteinDataTable[1,]
         ProteinInfoParsed <- as.data.frame(ProteinDataTable,row.names = ProteinAcc)
         # add Dataframes together if more than one accession
         ProteinInfoParsed_total <- rbind(ProteinInfoParsed_total, ProteinInfoParsed)
