@@ -23,6 +23,11 @@
 #'
 #'
 GetTaxonomic_lineage <- function(ProteinAccList , directorypath = NULL){
+  if(!has_internet())
+  {
+    message("Please connect to the internet as the package requires internect connection.")
+    return()
+  }
 
   # Sequences information to be collected
   columns <- c("lineage(all),lineage(SUPERKINGDOM),lineage(KINGDOM),lineage(SUBKINGDOM),lineage(SUPERPHYLUM),lineage(PHYLUM),lineage(SUBPHYLUM),lineage(SUPERCLASS),lineage(CLASS),lineage(SUBCLASS),lineage(INFRACLASS),lineage(SUPERORDER),lineage(ORDER),lineage(SUBORDER), lineage(INFRAORDER),lineage(PARVORDER),lineage(SUPERFAMILY),lineage(FAMILY),lineage(SUBFAMILY),lineage(TRIBE),lineage(SUBTRIBE),lineage(GENUS),lineage(SUBGENUS),lineage(SPECIES GROUP),lineage(SPECIES SUBGROUP),lineage(SPECIES),lineage(SUBSPECIES),lineage(VARIETAS),lineage(FORMA)")
@@ -33,8 +38,15 @@ GetTaxonomic_lineage <- function(ProteinAccList , directorypath = NULL){
   for (ProteinAcc in ProteinAccList)
   {
     #to see if Request == 200 or not
-    Request <- GET(paste0(baseUrl , ProteinAcc,".xml"))
-
+    Request <- tryCatch(
+      {
+        GET(paste0(baseUrl , ProteinAcc,".xml") , timeout(60))
+      },error = function(cond)
+      {
+        message("Internet connection problem occurs and the function will return the original error")
+        message(cond)
+      }
+    )
     #this link return information in tab formate (format = tab)
     #columns = what to return from all of the information (see: https://www.uniprot.org/help/uniprotkb_column_names)
     ProteinName_url <- paste0("?query=accession:",ProteinAcc,"&format=tab&columns=",columns)
@@ -46,6 +58,7 @@ GetTaxonomic_lineage <- function(ProteinAccList , directorypath = NULL){
       ProteinDataTable <- tryCatch(read.csv(RequestUrl, header = TRUE, sep = '\t'), error=function(e) NULL)
       if (!is.null(ProteinDataTable))
       {
+        ProteinDataTable <- ProteinDataTable[1,]
         ProteinInfoParsed <- as.data.frame(ProteinDataTable,row.names = ProteinAcc)
         # add Dataframes together if more than one accession
         ProteinInfoParsed_total <- rbind(ProteinInfoParsed_total, ProteinInfoParsed)
